# linear_model.SGDClassifier

Linear classifiers (SVM, logistic regression, a.o.) with SGD training.
This estimator implements regularized linear models with
stochastic gradient descent (SGD) learning: the gradient of
the loss is estimated each sample at a time and the model is
updated along the way with a decreasing strength schedule
(aka learning rate). SGD allows minibatch (online/out-of-core)
learning, see the partial_fit method. For best results using
the default learning rate schedule, the data should have zero mean
and unit variance.



        
### Usage
            
```javascript
import { SGDClassifier } from 'kalimdor/linear_model';
const clf = new SGDClassifier();
const X = [[0., 0.], [1., 1.]];
const y = [0, 1];
clf.fit({ X, y });
clf.predict({ X: [[2., 2.]] }); // result: [ 1 ]

```

        
### Constructors
            
* [constructor](#constructor)


        
### Methods
            
* [fit](#λ-fit)
            
* [fromJSON](#λ-fromjson)
            
* [predict](#λ-predict)
            
* [toJSON](#λ-tojson)




        
# Constructors
        
---
            
### constructor
            

            


                    
⊕ **new SGDClassifier**(__namedParameters: *&#x60;object&#x60;*)
                
Defined in [linear_model/stochastic_gradient.ts:15](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/linear_model/stochastic_gradient.ts#L15)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.clone | boolean | true | To clone the passed in dataset.
| options.epochs | number | 50 | Number of iterations.
| options.learningrate | number | 0.01 | Used to limit the amount each coefficient is corrected each time it is updated.
| options.preprocess | string | &quot;minmax&quot; | preprocess methodology can be either minmax or null. Default is minmax.

                        

                        
**Returns:** SGDClassifier






        
# Methods
        
---
                    
### λ fit
                    
Train the base SGD
                    

                
Defined in [linear_model/stochastic_gradient.ts:51](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/linear_model/stochastic_gradient.ts#L51)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.X | number[][] | null | Matrix of data
| options.y | number[] | null | Matrix of targets

                        
**Returns:**
                        
void
                    
### λ fromJSON
                    
Restore the model from a checkpoint
                    

                
Defined in [linear_model/stochastic_gradient.ts:126](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/linear_model/stochastic_gradient.ts#L126)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.coefficients | number[] | [] | coefficient values
| options.scaler | _type | null | scaler object such as MinMaxScaler

                        
**Returns:**
                        
void
                    
### λ predict
                    
Predicted values with Math.round applied
                    

                
Defined in [linear_model/stochastic_gradient.ts:238](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/linear_model/stochastic_gradient.ts#L238)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.X | number[][] | [] | Matrix of data

                        
**Returns:**
                        
number[]
                    
### λ toJSON
                    
Save the model&#x27;s checkpoint
                    

                
Defined in [linear_model/stochastic_gradient.ts:105](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/linear_model/stochastic_gradient.ts#L105)
                


                        
**Returns:**
                        
| Param | Type | Description |
| ------ | ------ | ------ |
| coefficients | number[] | coefficient values


