# preprocessing.MinMaxScaler

Transforms features by scaling each feature to a given range.
This estimator scales and translates each feature individually such that it is in the given range on the training set, i.e. between zero and one.

The transformation is given by:

```
X_std = (X - X.min(axis=0)) / (X.max(axis=0) - X.min(axis=0))
X_scaled = X_std * (max - min) + min
```

where min, max = feature_range.

This transformation is often used as an alternative to zero mean, unit variance scaling.



        
### Usage
            
```javascript
import { MinMaxScaler } from 'kalimdor/preprocessing';

const minmaxScaler = new MinMaxScaler({ featureRange: [0, 1] });
minmaxScaler.fit([4, 5, 6]);
const result = minmaxScaler.fit_transform([4, 5, 6]);
// [ 0, 0.5, 1 ]
```

        
### Constructors
            
* [constructor](#constructor)


        
### Methods
            
* [fit](#λ-fit)
            
* [fit_transform](#λ-fit-transform)
            
* [inverse_transform](#λ-inverse-transform)




        
# Constructors
        
---
            
### constructor
            

            


                    
⊕ **new MinMaxScaler**(__namedParameters: *&#x60;object&#x60;*)
                
Defined in [preprocessing/data.ts:385](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/preprocessing/data.ts#L385)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.clone | boolean | true | to clone the input
| options.featureRange | number[] | [0, 1] | scaling range

                        

                        
**Returns:** MinMaxScaler






        
# Methods
        
---
                    
### λ fit
                    
Compute the minimum and maximum to be used for later scaling.
                    

                
Defined in [preprocessing/data.ts:411](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/preprocessing/data.ts#L411)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| X | number[] or number[][] |  | Array or sparse-matrix data input

                        
**Returns:**
                        
void
                    
### λ fit_transform
                    
Fit to data, then transform it.
                    

                
Defined in [preprocessing/data.ts:435](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/preprocessing/data.ts#L435)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| X | number[] |  | Original input vector

                        
**Returns:**
                        
number[]
                    
### λ inverse_transform
                    
Undo the scaling of X according to feature_range.
                    

                
Defined in [preprocessing/data.ts:444](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/preprocessing/data.ts#L444)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| X | number[] |  | Scaled input vector

                        
**Returns:**
                        
number[]

